// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct AppointmentsView: View {
    @ObservedObject private var viewModel: ViewModel

    init() {
        self.viewModel = ViewModel()
    }

    var body: some View {
        NavigationView {
            VStack(spacing: 0) {
                DataLoadingView(state: viewModel.state,
                                animateStateChanges: true,
                                retryAction: { viewModel.fetchData() }, content: {
                                    ZStack(alignment: Alignment(horizontal: .center, vertical: .top)) {
                                        VStack(spacing: 0) {
                                            topFillerView
                                            bottomFillerView
                                        }

                                        content
                                    }
                                })

                InfoView(text: R.string.localizable.appointment_info())
            }
            .onAppear(perform: viewModel.fetchData)
            .navigationBarTitle(Text(R.string.localizable.bottom_navigation_title_appointments()), displayMode: .inline)
        }
        .navigationViewStyle(StackNavigationViewStyle())
    }

    // MARK: - Views

    private var content: some View {
        ScrollView {
            VStack(spacing: 0) {
                FinishedActivitiesView(years: viewModel.finishedActivities)
                    .padding(.leading)
                    .background(R.color.viewBackgroundSecondary.color())

                UnfinishedActivitiesView(years: viewModel.plannedActivities)
                    .padding(.leading)
                    .background(R.color.viewBackground.color())
            }
        }
    }

    private var topFillerView: some View {
        HStack {
            VerticalLineView(color: R.color.activitiesFinishedLine.color())
                .padding(.leading)

            Spacer()
        }
        .background(R.color.viewBackgroundSecondary.color())
    }

    private var bottomFillerView: some View {
        HStack {
            VerticalLineView(color: R.color.activitiesUnfinishedLine.color())
                .padding(.leading)

            Spacer()
        }
    }
}

struct AppointmentsView_Previews: PreviewProvider {
    static var previews: some View {
        AppointmentsView()
            .environment(\.colorScheme, .dark)
        AppointmentsView()
            .environment(\.colorScheme, .light)
    }
}
